@@ -1,6 +1,6 @@
 // Copyright (C)2004 Landmark Graphics Corporation
 // Copyright (C)2005, 2006 Sun Microsystems, Inc.
-// Copyright (C)2009-2011, 2014, 2018-2019 D. R. Commander
+// Copyright (C)2009-2011, 2014, 2018-2019, 2021 D. R. Commander
 //
 // This library is free software and may be redistributed and/or modified under
 // the terms of the wxWindows Library License, Version 3.1 or (at your option)
@@ -92,7 +92,7 @@ VGLTransReceiver::VGLTransReceiver(bool doSSL_, bool ipv6_, int drawMethod_) :
 
 	if((env = getenv("VGL_VERBOSE")) != NULL && strlen(env) > 0
 		&& !strncmp(env, "1", 1)) fbx_printwarnings(vglout.getFile());
-	NEWCHECK(thread = new Thread(this));
+	thread = new Thread(this);
 }
 
 
@@ -102,7 +102,7 @@ VGLTransReceiver::~VGLTransReceiver(void)
 	listenMutex.lock();
 	if(listenSocket) listenSocket->close();
 	listenMutex.unlock();
-	if(thread) { thread->stop();  thread = NULL; }
+	if(thread) { thread->stop();  delete thread;  thread = NULL; }
 }
 
 
@@ -110,7 +110,7 @@ void VGLTransReceiver::listen(unsigned short port_)
 {
 	try
 	{
-		NEWCHECK(listenSocket = new Socket(doSSL, ipv6));
+		listenSocket = new Socket(doSSL, ipv6);
 		port = listenSocket->listen(port_);
 	}
 	catch(...)
@@ -134,14 +134,14 @@ void VGLTransReceiver::run(void)
 			socket = listenSocket->accept();  if(deadYet) break;
 			vglout.println("++ %sConnection from %s.", doSSL ? "SSL " : "",
 				socket->remoteName());
-			NEWCHECK(listener = new Listener(socket, drawMethod));
+			listener = new Listener(socket, drawMethod);
 			continue;
 		}
-		catch(Error &e)
+		catch(std::exception &e)
 		{
 			if(!deadYet)
 			{
-				vglout.println("%s-- %s", e.getMethod(), e.getMessage());
+				vglout.println("%s-- %s", GET_METHOD(e), e.what());
 				delete listener;
 				delete socket;
 				continue;
@@ -251,9 +251,9 @@ void VGLTransReceiver::Listener::run(void)
 			}
 		}
 	}
-	catch(Error &e)
+	catch(std::exception &e)
 	{
-		vglout.println("%s-- %s", e.getMethod(), e.getMessage());
+		vglout.println("%s-- %s", GET_METHOD(e), e.what());
 	}
 	if(thread) { thread->detach();  delete thread;  thread = NULL; }
 	delete this;
@@ -296,7 +296,7 @@ ClientWin *VGLTransReceiver::Listener::addWindow(int dpynum, Window win,
 	}
 	if(nwin >= MAXWIN) THROW("No free window IDs");
 	if(dpynum < 0 || dpynum > 65535 || win == None) THROW("Invalid argument");
-	NEWCHECK(windows[winid] = new ClientWin(dpynum, win, drawMethod, stereo));
+	windows[winid] = new ClientWin(dpynum, win, drawMethod, stereo);
 
 	if(!windows[winid]) THROW("Could not create window instance");
 	nwin++;
